rule win_bluehaze_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bluehaze."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bluehaze"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 8d85f0feffff 50 8bcf ff15???????? 8b08 8b4904 }
            // n = 6, score = 100
            //   8d85f0feffff         | lea                 eax, [ebp - 0x110]
            //   50                   | push                eax
            //   8bcf                 | mov                 ecx, edi
            //   ff15????????         |                     
            //   8b08                 | mov                 ecx, dword ptr [eax]
            //   8b4904               | mov                 ecx, dword ptr [ecx + 4]

        $sequence_1 = { 745f 6a30 c7460800000000 e8???????? 83c404 85c0 }
            // n = 6, score = 100
            //   745f                 | je                  0x61
            //   6a30                 | push                0x30
            //   c7460800000000       | mov                 dword ptr [esi + 8], 0
            //   e8????????           |                     
            //   83c404               | add                 esp, 4
            //   85c0                 | test                eax, eax

        $sequence_2 = { 0fbe56ff 4e 51 52 57 ffd3 83c40c }
            // n = 7, score = 100
            //   0fbe56ff             | movsx               edx, byte ptr [esi - 1]
            //   4e                   | dec                 esi
            //   51                   | push                ecx
            //   52                   | push                edx
            //   57                   | push                edi
            //   ffd3                 | call                ebx
            //   83c40c               | add                 esp, 0xc

        $sequence_3 = { e8???????? 83c408 8bc8 ff15???????? 397314 7204 }
            // n = 6, score = 100
            //   e8????????           |                     
            //   83c408               | add                 esp, 8
            //   8bc8                 | mov                 ecx, eax
            //   ff15????????         |                     
            //   397314               | cmp                 dword ptr [ebx + 0x14], esi
            //   7204                 | jb                  6

        $sequence_4 = { 8d4f04 894e30 894e34 8d4708 8d4d10 894610 894614 }
            // n = 7, score = 100
            //   8d4f04               | lea                 ecx, [edi + 4]
            //   894e30               | mov                 dword ptr [esi + 0x30], ecx
            //   894e34               | mov                 dword ptr [esi + 0x34], ecx
            //   8d4708               | lea                 eax, [edi + 8]
            //   8d4d10               | lea                 ecx, [ebp + 0x10]
            //   894610               | mov                 dword ptr [esi + 0x10], eax
            //   894614               | mov                 dword ptr [esi + 0x14], eax

        $sequence_5 = { 68???????? 64a100000000 50 81ecec050000 a1???????? 33c5 8945ec }
            // n = 7, score = 100
            //   68????????           |                     
            //   64a100000000         | mov                 eax, dword ptr fs:[0]
            //   50                   | push                eax
            //   81ecec050000         | sub                 esp, 0x5ec
            //   a1????????           |                     
            //   33c5                 | xor                 eax, ebp
            //   8945ec               | mov                 dword ptr [ebp - 0x14], eax

        $sequence_6 = { 83c420 8d14c500000000 2bd0 8b06 5b 8d0cd0 }
            // n = 6, score = 100
            //   83c420               | add                 esp, 0x20
            //   8d14c500000000       | lea                 edx, [eax*8]
            //   2bd0                 | sub                 edx, eax
            //   8b06                 | mov                 eax, dword ptr [esi]
            //   5b                   | pop                 ebx
            //   8d0cd0               | lea                 ecx, [eax + edx*8]

        $sequence_7 = { 03c2 894508 753d 8b4604 8b0e 3bc8 0f8466010000 }
            // n = 7, score = 100
            //   03c2                 | add                 eax, edx
            //   894508               | mov                 dword ptr [ebp + 8], eax
            //   753d                 | jne                 0x3f
            //   8b4604               | mov                 eax, dword ptr [esi + 4]
            //   8b0e                 | mov                 ecx, dword ptr [esi]
            //   3bc8                 | cmp                 ecx, eax
            //   0f8466010000         | je                  0x16c

        $sequence_8 = { 0b0b 010b 0b0b 0b0b 0b0b 0b0b 0b0b }
            // n = 7, score = 100
            //   0b0b                 | or                  ecx, dword ptr [ebx]
            //   010b                 | add                 dword ptr [ebx], ecx
            //   0b0b                 | or                  ecx, dword ptr [ebx]
            //   0b0b                 | or                  ecx, dword ptr [ebx]
            //   0b0b                 | or                  ecx, dword ptr [ebx]
            //   0b0b                 | or                  ecx, dword ptr [ebx]
            //   0b0b                 | or                  ecx, dword ptr [ebx]

        $sequence_9 = { 33db 8bc7 8bf1 c745e80f000000 895de4 885dd4 8d5001 }
            // n = 7, score = 100
            //   33db                 | xor                 ebx, ebx
            //   8bc7                 | mov                 eax, edi
            //   8bf1                 | mov                 esi, ecx
            //   c745e80f000000       | mov                 dword ptr [ebp - 0x18], 0xf
            //   895de4               | mov                 dword ptr [ebp - 0x1c], ebx
            //   885dd4               | mov                 byte ptr [ebp - 0x2c], bl
            //   8d5001               | lea                 edx, [eax + 1]

    condition:
        7 of them and filesize < 424960
}